@@ -9,6 +9,8 @@ _known_files = set()
 
 
 def know_file(path: Path):
+    if not path.exists():
+        print(f"Well this is unexpected: The path {path} does not exist4")
     _known_files.add(path.resolve(strict=True))
 
 
