@@ -1,7 +1,8 @@
 import auto_dlp.file_locations as fs
 
 _unavailability_err_msgs = ["This video has been removed", "This video is not available", "This video is private",
-                            "This video is no longer available", "Video unavailable", "Private video"]
+                            "This video is no longer available", "Video unavailable", "Private video",
+                            "The uploader has not made this video available in your country"]
 
 
 def is_error_message_indicative_of_unavailability(msg):
